@@ -47,7 +47,7 @@ class Entity(object):
 
     def delete(self, id: str, parent_id=''):
         if self.DELETE_URL:
-            return self.api.request(method='DELETE', path=self.DELETE_URL.format(id=id, parent_id=parent_id))
+            return self._api.request(method='DELETE', path=self.DELETE_URL.format(id=id, parent_id=parent_id))
         raise MethodNotDefined('Delete')
 
     def search(self, search_text: str):
