@@ -6,6 +6,6 @@ from sky_api_client.entity.registry import EntityRegistry
 class EventParticipant(Entity):
     LIST_URL = '/event/v1/events/{id}/participants'
     CREATE_URL = '/event/v1/events/{id}/participants'
-    GET_URL = '/event/v1/events/{parent_id}/participants/{id}'
-    UPDATE_URL = '/event/v1/events/{parent_id}/participants/{id}'
-    DELETE_URL = '/event/v1/events/{parent_id}/participants/{id}'
+    GET_URL = '/event/v1/participants/{id}'
+    UPDATE_URL = '/event/v1/participants/{id}'
+    DELETE_URL = '/event/v1/participants/{id}'
\ No newline at end of file
